export const EXTENDED_FORMATS = {
    date: { day: "2-digit", month: "2-digit", year: "numeric" },
    time: { hour: "2-digit", minute: "2-digit", second: "2-digit" },
    full: { day: "2-digit", month: "2-digit", year: "numeric", hour: "2-digit", minute: "2-digit", second: "2-digit" },
    "date.short": { day: "2-digit", month: "2-digit" },
    "date.text": { day: "2-digit", month: "long", year: "numeric" },
    "date.text.short": { day: "2-digit", month: "short", year: "numeric" },
    "date.month": { day: "2-digit", month: "long" },
    "date.month.short": { day: "2-digit", month: "short" },
};
export const FORMATS = {
    date: { day: "2-digit", month: "2-digit", year: "numeric" },
    full: { day: "2-digit", month: "2-digit", year: "numeric", hour: "2-digit", minute: "2-digit", second: "2-digit" },
    "date.text": { day: "2-digit", month: "long", year: "numeric" },
};
export class DateFormatter {
    constructor(locale, optionsMap = FORMATS) {
        this.formatters = {};
        this.locale = locale;
        this.options = optionsMap;
    }
    format(format, date) {
        if (!this.formatters[format]) {
            let options = this.options[format];
            if (!options) {
                throw new Error(`Unknown format '${format}'`);
            }
            this.formatters[format] = new Intl.DateTimeFormat(this.locale, options);
        }
        return this.formatters[format].format(date).replace(/\u200E/g, "");
    }
}
