export function mediaQueryMatcher(query) {
    let media = window.matchMedia(query);
    let listeners = [];
    let updater = (event) => listeners.forEach(listener => listener(event.matches));
    if (media.addEventListener) {
        media.addEventListener("change", updater);
    }
    else {
        media.addListener(updater);
    }
    return {
        on(callback) {
            listeners.push(callback);
        },
        off(callback) {
            let index = listeners.indexOf(callback);
            if (-1 < index) {
                listeners.splice(index, 1);
            }
        },
        matches() {
            return media.matches;
        },
        onOff(callback) {
            this.on(callback);
            return () => this.off(callback);
        },
        destroy() {
            listeners = [];
            if (media.removeEventListener) {
                media.removeEventListener("change", updater);
            }
            else {
                media.removeListener(updater);
            }
        }
    };
}
