import fetch from "./polyfill/fetch";
import { extend } from "./extend";
export function isFailureResponse(response) {
    return response.reason && response.error;
}
export function isRequestFailure(response) {
    return response.reason && "request_failed" === response.reason;
}
export function isJsonFailure(response) {
    return response.reason && "invalid_json" === response.reason;
}
export function isStatusFailure(response) {
    return response.reason && "status" === response.reason;
}
export function request(url, options = {}) {
    let headers = extend(options.headers || {}, {
        Accept: "application/json",
        "X-Requested-With": "XMLHttpRequest",
    });
    let data = options.data;
    if (options.json !== undefined) {
        data = JSON.stringify(options.json);
        headers["Content-Type"] = "application/json; charset=UTF-8";
    }
    return new Promise((resolve, reject) => {
        fetch(url, {
            body: data,
            cache: "no-cache",
            credentials: false !== options.credentials ? "include" : "omit",
            headers: headers,
            method: options.method || "get",
        })
            .then(response => {
            return response.json()
                .then(data => {
                if ((response.status >= 200 && response.status < 300) || response.status === 400) {
                    return resolve({ data, response, success: response.status !== 400 });
                }
                reject({ response, data, reason: "status" });
            }, (error) => reject({ response, error, reason: "invalid_json" }));
        }, (error) => reject({ error, reason: "request_failed" }));
    });
}
