import { createUnstyledElement, toggleClass } from "../dom/manipulate";
import { inNextFrame } from "../timing";
export class OverlayLoader {
    constructor(spinnerHtml) {
        this.stack = [];
        this.spinnerHtml = spinnerHtml;
        this.overlay = createUnstyledElement('div', {
            class: "overlay-loader",
        });
        document.body.appendChild(this.overlay);
    }
    start(...messages) {
        this.stack.push(messages);
        this.render();
    }
    end() {
        this.stack.pop();
        this.render();
    }
    render() {
        toggleClass(this.overlay, "is-active", this.stack.length > 0);
        this.overlay.innerHTML = "";
        if (this.stack.length) {
            const element = createUnstyledElement(`
                <div class="loader">
                    <div class="loader-graphic">${this.spinnerHtml}</div>
                </div>
            `);
            const messages = this.stack[this.stack.length - 1];
            if (messages.length) {
                const messageElement = createUnstyledElement('div', {
                    class: "loader-message",
                });
                element.appendChild(messageElement);
                messages.forEach(line => messageElement.appendChild(createUnstyledElement("span", {
                    text: line,
                })));
            }
            this.overlay.appendChild(element);
            inNextFrame(() => this.overlay.classList.add("is-visible"));
        }
        else {
            this.overlay.classList.remove("is-visible");
        }
    }
}
