import { h, render } from "preact";
import { createUnstyledElement } from "../dom/manipulate";
import { inNextFrame } from "../timing";
import { DefaultToast } from "./Toast/DefaultToast";
import { calculateToastDuration } from "./toasts-helper";
const TRANSITION_DURATION = 400 + 200;
export class ToastManager {
    constructor(toastImplementation) {
        this.queue = [];
        this.hasVisible = false;
        this.hideTimeout = null;
        this.toastImplementation = toastImplementation || DefaultToast;
        this.container = createUnstyledElement('div', {
            class: "toast-container",
        });
        document.body.appendChild(this.container);
    }
    neutral(text, action) {
        this.add(text, "neutral", action);
    }
    positive(text, action) {
        this.add(text, "positive", action);
    }
    negative(text, action) {
        this.add(text, "negative", action);
    }
    add(text, impact, action) {
        this.queue.push({
            impact: impact || "neutral",
            text,
            action,
        });
        this.show();
    }
    show() {
        if (this.hasVisible) {
            return;
        }
        const toast = this.queue.shift();
        if (!toast) {
            return;
        }
        this.hasVisible = true;
        let action = toast.action;
        if (action && typeof action.action === "function") {
            let oldCallback = action.action;
            action = {
                label: action.label,
                action: () => {
                    this.abortShow();
                    oldCallback();
                }
            };
        }
        const Toast = this.toastImplementation;
        render(h(Toast, { action: action, impact: toast.impact }, toast.text), this.container);
        inNextFrame(() => this.beforeShow(toast));
    }
    abortShow() {
        if (this.hideTimeout) {
            window.clearTimeout(this.hideTimeout);
            this.beforeHide();
        }
    }
    beforeShow(toast) {
        this.container.classList.add("is-visible");
        this.hideTimeout = window.setTimeout(() => this.beforeHide(), TRANSITION_DURATION + calculateToastDuration(toast.text, toast.action));
    }
    beforeHide() {
        this.hideTimeout = null;
        this.container.classList.remove("is-visible");
        window.setTimeout(() => this.afterHide(), TRANSITION_DURATION);
    }
    afterHide() {
        render(null, this.container);
        this.container.innerHTML = "";
        this.hasVisible = false;
        this.show();
    }
}
