export class Slug {
    constructor(transforms = [], sanitize = null) {
        this.transforms = [];
        this.sanitize = null !== sanitize
            ? sanitize
            : /[^a-z0-9\-._~(),;!]/g;
        transforms = transforms.concat([
            [/ä/, "ae"],
            [/[áâà]/, "a"],
            [/ö/, "oe"],
            [/[óôò]/, "o"],
            [/ü/, "ue"],
            [/[úûù]/, "u"],
            [/ß/, "ss"],
        ]);
        for (let i = 0; i < transforms.length; i++) {
            let from = transforms[i][0];
            if (from instanceof RegExp) {
                let regexMatch = /^\/.*?\/([^g\/]*)$/.exec(from.toString());
                if (null !== regexMatch) {
                    from = new RegExp(from.source, `${regexMatch[1]}g`);
                }
            }
            this.transforms.push([
                from,
                transforms[i][1],
            ]);
        }
    }
    transform(raw) {
        raw = raw.toLowerCase();
        for (let i = 0; i < this.transforms.length; i++) {
            raw = raw.replace(this.transforms[i][0], this.transforms[i][1]);
        }
        return raw
            .replace(this.sanitize, "-")
            .replace(/-+/g, "-")
            .replace(/^-|-$/g, "");
    }
}
